netapp_ontap.models.data_engine_version_job API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_version_job`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineVersionJobSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineVersionJob object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the data_engine_version_job.

  `state: str GET`

    The state of the data engine job:

    - queued - The job is queued for execution.
    - running - The job is currently in execution.
    - success - The job has been completed successfully.
    - failure - The job has failed.

    Valid choices:

    - queued
    - running
    - success
    - failure
  `uuid: str GET`

    The unique identifier of the job.

    Example: 123e4567-e89b-12d3-a456-426614174000